/*  This file is part of the KDE project
    Copyright (C) 2007 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this library
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#include <qlabel.h>
#include <qtooltip.h>
#include <kiconloader.h>
#include <klocale.h>

#include "connectionmanager.h"

#include "networkstatusindicator.h"

StatusBarNetworkStatusIndicator::StatusBarNetworkStatusIndicator(
    QWidget * parent, const char * name ) : QHBox( parent, name )/*, d( new StatusBarNetworkStatusIndicatorPrivate )*/
{
  setMargin( 2 );
  setSpacing( 1 );
  QLabel * label = new QLabel( this, "offlinemodelabel" );
  label->setPixmap( SmallIcon("connect_no") );
  QToolTip::add( label, i18n( "The desktop is offline" ) );

  connect( ConnectionManager::self(), SIGNAL( statusChanged( NetworkStatus::Status ) ),
      SLOT( networkStatusChanged( NetworkStatus::Status) ) );

}

void StatusBarNetworkStatusIndicator::init()
{
  networkStatusChanged( ConnectionManager::self()->status());
}

StatusBarNetworkStatusIndicator::~StatusBarNetworkStatusIndicator()
{
}

void StatusBarNetworkStatusIndicator::networkStatusChanged( NetworkStatus::Status status )
{
  if ( status == NetworkStatus::Online || status == NetworkStatus::NoNetworks ) {
    hide();
  } else {
    show();
  }
}

#include "networkstatusindicator.moc"
